@@ -116,33 +116,22 @@ module Exploit::Remote::HttpServer
   # completely on the datastore. (See dlink_upnp_exec_noauth)
   def start_service(opts = {})
 
+    # Keep compatibility with modules that don't pass the ssl option to the start server but rely on the datastore instead.
+    opts['ssl'] = opts['ssl'].nil? ? datastore['SSL'] : opts['ssl']
+
     check_dependencies
 
-    comm = datastore['ListenerComm']
-    if (comm.to_s == "local")
-      comm = ::Rex::Socket::Comm::Local
-    else
-      comm = nil
-    end
-
-    # Default the server host and port to what is required by the mixin.
-    opts = {
-      'ServerHost' => datastore['SRVHOST'],
-      'ServerPort' => datastore['SRVPORT'],
-      'Comm'       => comm
-    }.update(opts)
-
     # Start a new HTTP server service.
     self.service = Rex::ServiceManager.start(
       Rex::Proto::Http::Server,
-      opts['ServerPort'].to_i,
-      opts['ServerHost'],
-      datastore['SSL'], # XXX: Should be in opts, need to test this
+      (opts['ServerPort'] || bindport).to_i,
+      opts['ServerHost'] || bindhost,
+      opts['ssl'],
       {
         'Msf'        => framework,
         'MsfExploit' => self,
       },
-      opts['Comm'],
+      opts['Comm'] || _determine_server_comm(opts['ServerHost'] || bindhost),
       datastore['SSLCert'],
       datastore['SSLCompression'],
       datastore['SSLCipher'],
@@ -163,7 +152,7 @@ module Exploit::Remote::HttpServer
       'Path' => opts['Path'] || resource_uri
     }.update(opts['Uri'] || {})
 
-    proto = (datastore["SSL"] ? "https" : "http")
+    proto = (opts['ssl'] ? "https" : "http")
 
     # SSLCompression may or may not actually be available. For example, on
     # Ubuntu, it's disabled by default, unless the correct environment
@@ -172,19 +161,18 @@ module Exploit::Remote::HttpServer
       print_status("Intentionally using insecure SSL compression. Your operating system might not respect this!")
     end
 
-
-    print_status("Using URL: #{proto}://#{opts['ServerHost']}:#{opts['ServerPort']}#{uopts['Path']}")
-
-    if opts['ServerHost'] == '0.0.0.0'
-      print_status("Local IP: #{proto}://#{Rex::Socket.source_address('1.2.3.4')}:#{opts['ServerPort']}#{uopts['Path']}")
-    end
-
-    if datastore['SendRobots']
-      add_robots_resource
+    netloc = srvhost_addr
+    if (proto == 'http' && srvport  != 80) || (proto == 'https' && srvport != 443)
+      if Rex::Socket.is_ipv6?(netloc)
+        netloc = "[#{netloc}]:#{srvport}"
+      else
+        netloc = "#{netloc}:#{srvport}"
+      end
     end
+    print_status("Using URL: #{proto}://#{netloc}#{uopts['Path']}")
 
+    add_robots_resource if datastore['SendRobots']
     add_resource(uopts)
-
   end
 
   def add_robots_resource
@@ -393,7 +381,14 @@ module Exploit::Remote::HttpServer
     report_note(
       :host => address,
       :type => 'http.request',
-      :data => "#{address}: #{request.method} #{request.resource} #{client[:os_name]} #{client[:ua_name]} #{client[:ua_ver]}",
+      :data => {
+        :address => address,
+        :method => request.method,
+        :resource => request.resource,
+        :os_name => client[:os_name],
+        :ua_name => client[:ua_name],
+        :ua_ver => client[:ua_ver]
+      },
       :update => :unique_data
     )
     return host.merge(client)
