@@ -28,6 +28,11 @@ class MetasploitModule < Msf::Auxiliary
         [ 'URL', 'https://datatracker.ietf.org/doc/html/rfc5321' ],
         [ 'URL', 'http://fehcom.de/qmail/smtpauth.html' ]
       ],
+      'Notes' => {
+        'Stability' => [CRASH_SAFE],
+        'SideEffects' => [],
+        'Reliability' => []
+      }
     )
 
     register_options(
@@ -53,7 +58,7 @@ class MetasploitModule < Msf::Auxiliary
     data = data.drop(1)
 
     # if only a username is submitted, it will appear as \00un\00
-    # we already cut off the empty username, so nowe we want to add on the empty password
+    # we already cut off the empty username, so now we want to add on the empty password
     if data.length == 1
       data << ''
     end
@@ -71,7 +76,7 @@ class MetasploitModule < Msf::Auxiliary
 
     print_status("SMTP: #{@state[client][:name]} Command: #{data.strip}")
 
-    if (@state[client][:data_mode])
+    if @state[client][:data_mode]
       @state[client][:data_buff] ||= ''
       @state[client][:data_buff] += data
 
@@ -83,7 +88,7 @@ class MetasploitModule < Msf::Auxiliary
         report_note(
           host: @state[client][:ip],
           type: 'smtp_message',
-          data: @state[client][:data_buff][0, idx]
+          data: { :message => @state[client][:data_buff][0, idx] }
         )
         @state[client][:data_buff][0, idx].split("\n").each do |line|
           print_status("SMTP: #{@state[client][:name]} EMAIL: #{line.strip}")
@@ -97,7 +102,7 @@ class MetasploitModule < Msf::Auxiliary
       return
     end
 
-    if (@state[client][:auth_login])
+    if @state[client][:auth_login]
       if @state[client][:user].nil?
         @state[client][:user] = Rex::Text.decode_base64(data)
         client.put "334 #{Rex::Text.encode_base64('Password')}\r\n"
@@ -118,7 +123,7 @@ class MetasploitModule < Msf::Auxiliary
       return
     end
 
-    if (@state[client][:auth_plain])
+    if @state[client][:auth_plain]
       # this data is \00 delimited, and has 3 fields: un\00un\00\pass.  Not sure why a double username
       un_pass = auth_plain_parser data
 
@@ -138,7 +143,7 @@ class MetasploitModule < Msf::Auxiliary
       return
     end
 
-    if (@state[client][:auth_cram])
+    if @state[client][:auth_cram]
       # data is <username><space><digest aka hash>
       decoded = Rex::Text.decode_base64(data).split(' ')
       @state[client][:user] = decoded.first
